@@ -180,8 +180,11 @@ class GenerateCitationNet():
         tmpSearch = self.solr.search(searchStr, **flDict)
         tmpResIN = [x for x in tmpSearch]
         tmpRes = []
-        for elem in tmpResIN:
-            tmpRes.append(self.getNodeData(elem, direction='source'))
+        if tempResIN:
+            for elem in tmpResIN:
+                tmpRes.append(self.getNodeData(elem, direction='source'))
+        else:
+            return pd.DataFrame(), (time.time() - start_time)
         dfOut = pd.DataFrame(tmpRes)
         dfOut.insert(0, 'targetJournal', injournal)
         dfOut.insert(0, 'targetDOI', doi)
